// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.json;

import java.lang.reflect.Type;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.function.BiFunction;

class UrlCoercer extends TypeCoercer<URL> {

  @Override
  public boolean test(Class<?> type) {
    return URL.class.isAssignableFrom(type);
  }

  @Override
  public BiFunction<JsonInput, PropertySetting, URL> apply(Type type) {
    return (jsonInput, propertySetting) -> {
      String toCoerce;

      switch (jsonInput.peek()) {
        case NAME:
          toCoerce = jsonInput.nextName();
          break;

        case STRING:
          toCoerce = jsonInput.nextString();
          break;

        default:
          throw new JsonException("Unable to coerce type to URL: " + jsonInput.peek());
      }

      try {
        return new URL(toCoerce);
      } catch (MalformedURLException e) {
        throw new JsonException(e);
      }
    };
  }
}
